@@ -14,18 +14,18 @@
 #include <fcntl.h>
 #include <io.h>
 #include <envfs.h>
-#include <mach/hardware.h>
+#include <mach/at91/hardware.h>
 #include <nand.h>
 #include <linux/sizes.h>
 #include <linux/mtd/nand.h>
 #include <linux/mtd/rawnand.h>
 #include <linux/clk.h>
-#include <mach/board.h>
-#include <mach/at91sam9_smc.h>
+#include <mach/at91/board.h>
+#include <mach/at91/at91sam9_smc.h>
 #include <gpio.h>
-#include <mach/iomux.h>
-#include <mach/at91_pmc.h>
-#include <mach/at91_rstc.h>
+#include <mach/at91/iomux.h>
+#include <mach/at91/at91_pmc.h>
+#include <mach/at91/at91_rstc.h>
 #include <local_mac_address.h>
 
 static bool animeo_ip_is_buco;
