@@ -166,10 +166,6 @@ static int hf_probe(struct device *dev)
 		if (err)
 			return err;
 
-		err = parse_partition_table(&priv->blk);
-		if (err)
-			dev_warn(dev, "No partition table found\n");
-
 		dev_info(dev, "registered as block device\n");
 	} else {
 		cdev->name = np->name;
@@ -188,7 +184,7 @@ static int hf_probe(struct device *dev)
 	of_parse_partitions(cdev, np);
 	of_partitions_register_fixup(cdev);
 
-	return 0;
+	return of_platform_populate(np, NULL, dev);
 }
 
 static __maybe_unused struct of_device_id hostfile_dt_ids[] = {
