@@ -17,7 +17,6 @@
 #include <regmap.h>
 
 #ifdef CONFIG_MFD_SYSCON
-void __iomem *syscon_base_lookup_by_pdevname(const char *s);
 void __iomem *syscon_base_lookup_by_phandle
 	(struct device_node *np, const char *property);
 struct regmap *syscon_node_to_regmap(struct device_node *np);
@@ -27,11 +26,6 @@ extern struct regmap *syscon_regmap_lookup_by_phandle(
 					struct device_node *np,
 					const char *property);
 #else
-static inline void __iomem *syscon_base_lookup_by_pdevname(const char *s)
-{
-	return ERR_PTR(-ENOSYS);
-}
-
 static inline void __iomem *syscon_base_lookup_by_phandle
 	(struct device_node *np, const char *property)
 {
